@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: horde/lib/Horde.php,v 1.118.2.39 2003/01/17 00:58:35 slusarz Exp $
+ * $Horde: horde/lib/Horde.php,v 1.118.2.42 2003/04/23 21:43:06 jan Exp $
  *
  * Copyright 1999-2003 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2003 Jon Parise <jon@horde.org>
@@ -120,7 +120,7 @@ function _fileCleanup($filename = false, $register = true)
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.118.2.39 $
+ * @version $Revision: 1.118.2.42 $
  * @since   Horde 1.3
  * @package horde
  */
@@ -160,7 +160,7 @@ class Horde {
      */
     function logMessage($message, $file, $line, $priority = LOG_INFO)
     {
-        static $logger;
+        static $logcheck;
         global $conf;
 
         if (!$conf['log']['enabled']) {
@@ -171,9 +171,7 @@ class Horde {
             return;
         }
 
-        if (!isset($logger)) {
-            include_once 'Log.php';
-
+        if (!isset($logcheck)) {
             // Try to make sure that we can log messages somehow.
             if (!array_key_exists('log', $conf) ||
                 !array_key_exists('type', $conf['log']) ||
@@ -182,17 +180,15 @@ class Horde {
                 !array_key_exists('params', $conf['log'])) {
                 Horde::fatal(new PEAR_Error('Horde is not correctly configured to log error messages. You must configure at least a text file log in horde/config/horde.php.'), __FILE__, __LINE__, false);
             }
+            $logcheck = true;
+        }
 
-            $logger = &Log::singleton($conf['log']['type'], $conf['log']['name'],
-                                      $conf['log']['ident'], $conf['log']['params']);
+        include_once 'Log.php';
+        $logger = Log::singleton($conf['log']['type'], $conf['log']['name'],
+                                 $conf['log']['ident'], $conf['log']['params']);
 
-            if (!$logger || !is_object($logger) || !is_subclass_of($logger, 'log')) {
-                if (PEAR::isError($logger)) {
-                    Horde::fatal($logger, __FILE__, __LINE__, false);
-                } else {
-                    Horde::fatal(new PEAR_Error('An error has occurred. Furthermore, Horde encountered an error attempting to log this error.'), __FILE__, __LINE__, false);
-                }
-            }
+        if (!$logger) {
+            Horde::fatal(new PEAR_Error('An error has occurred. Furthermore, Horde encountered an error attempting to log this error. Please check your Horde logging configuration in horde/config/horde.php.'), __FILE__, __LINE__, false);
         }
 
         if (PEAR::isError($message)) {
@@ -588,8 +584,8 @@ HTML;
         $img .= ' border="0"';
         if (!empty($attr)) {
             $img .= ' ' . $attr;
-            if (preg_match('/alt=[\'"]([^\'"]*)[\'"]/i', $attr, $match)) {
-                $img .= ' title="'. $match[1] . '"';
+            if (preg_match('/alt=([\'"])([^\1]*)\1/i', $attr, $match)) {
+                $img .= ' title="'. $match[2] . '"';
             }
         }
         if (empty($attr) || !strstr($attr, 'alt')) {
