@@ -1,12 +1,19 @@
 <?php
-// $Horde: horde/lib/MIME/Viewer/msword.php,v 1.9.2.2 2002/04/05 01:24:30 jon Exp $
+/*
+ * $Horde: horde/lib/MIME/Viewer/msword.php,v 1.9.2.5 2003/01/03 12:48:27 jan Exp $
+ *
+ * Copyright 1999-2003 Anil Madhavapeddy <anil@recoil.org>
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ */
 
 /**
  * The MIME_Viewer_msword class renders out Microsoft Word
  * documents in HTML format by using the wvWare package.
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.9.2.2 $
+ * @version $Revision: 1.9.2.5 $
  * @since   Horde 1.3
  * @package horde.mime.viewer
  */
@@ -23,6 +30,11 @@ class MIME_Viewer_msword extends MIME_Viewer {
     {
         global $mime_drivers;
 
+        /* Check to make sure the program actually exists. */
+        if (file_exists($mime_drivers['horde']['msword']['location']) === false) {
+            return '<pre>' . sprintf(_("The program used to view this message type (%s) was not found on the system."), $mime_drivers['horde']['msword']['location']) . '</pre>';
+        }
+
         $tmp_word   = Horde::getTempFile('msword');
         $tmp_output = Horde::getTempFile('msword');
         $tmp_dir    = Horde::getTempDir();
