@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: horde/lib/Prefs/ldap.php,v 1.14.2.18 2003/01/17 10:22:17 jan Exp $
+ * $Horde: horde/lib/Prefs/ldap.php,v 1.14.2.19 2003/02/17 23:57:58 jan Exp $
  *
  * Copyright 1999-2003 Jon Parise <jon@horde.org>
  *
@@ -28,7 +28,7 @@ Horde::functionCheck('ldap_connect', true,
  *      'password'      'username's password for bind authentication.
  *
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.14.2.18 $
+ * @version $Revision: 1.14.2.19 $
  * @since   Horde 1.3
  * @package horde.prefs
  */
@@ -348,7 +348,9 @@ class Prefs_ldap extends Prefs {
         /* ldap_get_entries() converts attribute indexes to lowercase. */
         $field = strtolower($this->scope . 'prefs');
 
-        if (isset($result)) {
+        if (isset($result[0]['hordeprefs'])) {
+            $prefs = array();
+
             /*
              * Set the requested values in the $this->prefs hash based on
              * the contents of the LDAP result.
@@ -369,10 +371,14 @@ class Prefs_ldap extends Prefs {
                     $prefs = array_merge($result[0][$field],
                                          $result[0]['hordeprefs']);
                 } else {
-                    $prefs = $result[0]['hordeprefs'];
+                    if (isset($result[0]['hordeprefs'])) {
+                        $prefs = $result[0]['hordeprefs'];
+                    }
                 }
             } else {
-                $prefs = $result[0][$field];
+                if (isset($result[0][$field])) {
+                    $prefs = $result[0][$field];
+                }
             }
 
             foreach ($prefs as $prefstr) {
