@@ -6,7 +6,7 @@
  * For usage information call it like:
  * ./translation.php help
  *
- * $Horde: horde/po/translation.php,v 1.27.2.2 2002/12/27 15:01:31 jan Exp $
+ * $Horde: horde/po/translation.php,v 1.27.2.6 2003/02/19 22:56:39 jan Exp $
  */
 
 function writeln($text = '', $pre = false)
@@ -467,24 +467,19 @@ function make()
                         writeln(red(_("Warning: ")) . sprintf(_("Could not create locale directory for locale %s:"), $locale));
                         writeln($d);
                         writeln();
-                        continue 2;
+                        continue;
                     }
                 }
             }
-            print _("Setting PO-Revision-Date to current time... ");
             $pofile = $dirs[$i] . '/po/' . $locale . '.po';
-            $date = date('Y-m-d H:iO');
-            $sh = "sed 's/PO-Revision-Date: ....-..-.. ..:..+..../PO-Revision-Date: $date/' $pofile " .
-                  "> $pofile.tmp";
+            $sh = "cat $pofile | tr -d '\\r' > $pofile.tmp";
             if ($debug || $test) {
                 writeln();
                 writeln(_("Executing:"));
                 writeln($sh);
             }
-            if ($test) {
-                $ret = 0;
-            } else {
-                exec($sh, $out, $ret);
+            if (!$test) {
+                exec($sh);
             }
             $sh = "mv $pofile.tmp $pofile";
             if ($debug || $test) {
@@ -492,16 +487,9 @@ function make()
                 writeln(_("Executing:"));
                 writeln($sh);
             }
-            if ($test) {
-                $ret = 0;
-            } else {
+            if (!$test) {
                 exec($sh);
             }
-            if ($ret == 0) {
-                writeln();
-            } else {
-                writeln(red(_("failed")));
-            }
             $sh = $GLOBALS['msgfmt'] . ' --check ' . $pofile . ' 2>&1';
             if ($debug || $test) {
                 writeln(_("Executing:"));
@@ -796,13 +784,13 @@ function update_help()
             if (preg_match('/encoding=(["\'])([^\\1]+)\\1/', $line, $match)) {
                 $encoding = $match[2];
             }
-            $doc_en   = domxml_open_file($file_en);
+            $doc_en = domxml_open_file($file_en);
             if (!is_object($doc_en)) {
                 writeln(wordwrap(red(_("Warning: ")) . sprintf(_("There was an error opening the file %s. Try running translation.php with the flag -d to see any error messages from the xml parser."), $file_en)));
                 writeln();
                 continue 2;
             }
-            $doc_loc  = domxml_open_file($file_loc);
+            $doc_loc = domxml_open_file($file_loc);
             if (!is_object($doc_loc)) {
                 writeln(wordwrap(red(_("Warning: ")) . sprintf(_("There was an error opening the file %s. Try running translation.php with the flag -d to see any error messages from the xml parser."), $file_loc)));
                 writeln();
@@ -826,14 +814,14 @@ function update_help()
                 if (array_key_exists($id, $entries_loc)) {
                     if ($entries_loc[$id]->has_attribute('md5') &&
                         md5($entry->get_content()) != $entries_loc[$id]->get_attribute('md5')) {
-                        $comment = $doc_loc->create_comment(" English entry:\n" . str_replace('--', '&#45;&#45;', $entry->dump_node($entry)));
+                        $comment = $doc_loc->create_comment(" English entry:\n" . str_replace('--', '&#45;&#45;', $doc_loc->dump_node($entry)));
                         $entries_loc[$id]->append_child($comment);
                         $entry_new = $entries_loc[$id]->clone_node(true);
                         $entry_new->set_attribute('state', 'changed');
                         $count_changed++;
                     } else {
                         if (!$entries_loc[$id]->has_attribute('state')) {
-                            $comment = $doc_loc->create_comment(" English entry:\n" . str_replace('--', '&#45;&#45;', $entry->dump_node($entry)));
+                            $comment = $doc_loc->create_comment(" English entry:\n" . str_replace('--', '&#45;&#45;', $doc_loc->dump_node($entry)));
                             $entries_loc[$id]->append_child($comment);
                             $entry_new = $entries_loc[$id]->clone_node(true);
                             $entry_new->set_attribute('state', 'unknown');
