@@ -1,10 +1,10 @@
 <?php
-/*
- * $Horde: horde/test.php,v 1.44.2.8 2002/06/10 15:00:22 jan Exp $
+/**
+ * $Horde: horde/test.php,v 1.44.2.21 2003/04/22 18:23:30 slusarz Exp $
  *
- * Copyright 2002 Brent J. Nordquist <bjn@horde.org>
- * Copyright 1999-2002 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2002 Jon Parise <jon@horde.org>
+ * Copyright 2002-2003 Brent J. Nordquist <bjn@horde.org>
+ * Copyright 1999-2003 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2003 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -12,12 +12,12 @@
 
 @session_start();
 /* Register a session. */
-if (!isset($HTTP_SESSION_VARS['horde_test_count'])) {
+if (!isset($_SESSION['horde_test_count'])) {
     $horde_test_count = 0;
     session_register('horde_test_count');
 }
 
-$horde_test_count = &$HTTP_SESSION_VARS['horde_test_count'];
+$horde_test_count = &$_SESSION['horde_test_count'];
 
 /* We want to be as verbose as possible here. */
 error_reporting(E_ALL);
@@ -27,19 +27,24 @@ header('Content-type: text/html; charset=utf-8');
 header('Vary: Accept-Language');
 
 function testErrorHandler($errno, $errmsg, $filename, $linenum, $vars) {
-    global $pear, $newpear, $pearmail, $pearlog, $peardb, $unkerr;
-    if (preg_match("/PEAR\.php/", $errmsg)) {
+    global $pear, $newpear, $pearmail, $pearlog, $peardb,
+           $pearsocket, $peardate, $pearhtml, $unkerr;
+    if (preg_match('/PEAR\.php/', $errmsg)) {
         $pear = false;
-    } elseif (preg_match("/IT_Error\.php/", $errmsg)) {
-        $newpear = false;
-    } elseif (preg_match("/RFC822\.php/", $errmsg)) {
+    } elseif (preg_match('/RFC822\.php/', $errmsg)) {
         $pearmail = false;
-    } elseif (preg_match("/Log\.php/", $errmsg)) {
+    } elseif (preg_match('/Log\.php/', $errmsg)) {
         $pearlog = false;
-    } elseif (preg_match("/DB\.php/", $errmsg)) {
+    } elseif (preg_match('/DB\.php/', $errmsg)) {
         $peardb = false;
+    } elseif (preg_match('/Socket\.php/', $errmsg)) {
+        $pearsocket = false;
+    } elseif (preg_match('/Calc\.php/', $errmsg)) {
+        $peardate = false;
+    } elseif (preg_match('/Common\.php/', $errmsg) || preg_match('/Select\.php/', $errmsg)) {
+        $pearhtml = false;
     } else {
-        $unkerr = $errmsg;
+        $unkerr = "$errmsg ($filename:$linenum)";
     }
 }
 
@@ -51,6 +56,16 @@ function status($foo) {
     }
 }
 
+/* If gettext is not loaded, define a dummy _() function so that
+ * including registry.php (which contains gettext strings) won't cause
+ * a fatal error, causing test.php to return a blank page. */
+if (!function_exists('_')) {
+    function _($s)
+    {
+        return $s;
+    }
+}
+
 /* Horde versions */
 $versions = array();
 $testphp = array();
@@ -61,12 +76,15 @@ $versions['horde'] = HORDE_VERSION;
 $this->applications = array();
 @include_once './config/registry.php';
 foreach ($this->applications as $module => $details) {
-    if (@is_readable($details['fileroot'] . '/lib/version.php')) {
+    if (is_readable($details['fileroot'] . '/lib/version.php')) {
         include_once $details['fileroot'] . '/lib/version.php';
-        eval('$ver = ' . strtoupper($module) . '_VERSION;');
-        $versions[$module] = $ver;
-        if ($module != 'horde' && @is_readable($details['fileroot'] . '/test.php')) {
-            $testphp[$module] = $details['webroot'] . '/test.php';
+        eval('$defined = defined(\'' . strtoupper($module) . '_VERSION\');');
+        if ($defined) {
+            eval('$ver = ' . strtoupper($module) . '_VERSION;');
+            $versions[$module] = $ver;
+            if ($module != 'horde' && @is_readable($details['fileroot'] . '/test.php')) {
+                $testphp[$module] = $details['webroot'] . '/test.php';
+            }
         }
     }
 }
@@ -153,25 +171,35 @@ $mcrypt = extension_loaded('mcrypt');
 $mysql = extension_loaded('mysql');
 $pgsql = extension_loaded('pgsql');
 $xml = extension_loaded('xml');
+$domxml = extension_loaded('domxml');
 
 /* PHP Settings */
 $magic_quotes_runtime = !get_magic_quotes_runtime();
 $file_uploads = ini_get('file_uploads');
-$short_open_tag = ini_get('short_open_tag');
+$safe_mode = !ini_get('safe_mode');
+$trans_sid = !ini_get('session.trans_sid');
 
 /* PEAR */
 $pear = true;
-$newpear = true;
 $pearmail = true;
 $pearlog = true;
 $peardb = true;
-$unkerr = "";
+$pearsocket = true;
+$peardate = true;
+$pearhtml = true;
+$unkerr = '';
 set_error_handler('testErrorHandler');
 include 'PEAR.php';
-include 'HTML/IT_Error.php';  # new in 4.0.7RC
 include 'Mail/RFC822.php';
+include 'Mail/mimeDecode.php';
 include 'Log.php';
 include 'DB.php';
+include 'Net/Socket.php';
+include 'Date/Calc.php';
+include 'HTML/Common.php';
+if ($pearhtml) {
+    include 'HTML/Select.php';
+}
 restore_error_handler();
 
 /* Check the version of the pear database API. */
@@ -183,18 +211,22 @@ if ($peardb) {
     }
 }
 
+/* Test for existence of PEAR::registerShutdownFunc() */
+$pear_methods = get_class_methods('PEAR');
+$newpear = is_array($pear_methods) && in_array('registershutdownfunc', $pear_methods);
+
 echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "DTD/xhtml1-transitional.dtd">';
 
 /* Handle special modes */
-if (isset($HTTP_GET_VARS['mode'])) {
-    switch ($HTTP_GET_VARS['mode']) {
+if (isset($_GET['mode'])) {
+    switch ($_GET['mode']) {
     case 'phpinfo':
         phpinfo();
         exit;
         break;
 
     case 'unregister':
-        $HTTP_SESSION_VARS['horde_test_count'] = null;
+        $_SESSION['horde_test_count'] = null;
         session_unregister('horde_test_count');
         ?>
         <html>
@@ -265,7 +297,7 @@ foreach ($versions as $module => $ver) {
     } elseif ($phpver['major'] == '4.0') {
         echo '        <li><font color="red">This version of PHP is not supported. You need to upgrade to a more recent version.</font></li>';
         $requires = 1;
-    } elseif ($phpver['major'] == '4.1' || $phpver['major'] == '4.2' || $phpver['major'] == '4.3') {
+    } elseif ($phpver['major'] == '4.1' || $phpver['major'] == '4.2' || $phpver['major'] == '4.3' || $phpver['major'] == '4.4') {
         if ($phpver['major'] == '4.1' && $phpver['minor'] < '2') {
             $insecure = 1;
         }
@@ -284,6 +316,7 @@ foreach ($versions as $module => $ver) {
 
 <h1>PHP Module Capabilities</h1>
 <ul>
+    <li>DOM XML Support: <?php status($domxml); ?></li>
     <li>FTP Support: <?php status($ftp); ?></li>
     <li>Gettext Support: <?php status($gettext); ?></li>
     <?php if (!$gettext) { ?>
@@ -300,11 +333,7 @@ foreach ($versions as $module => $ver) {
 
 <h1>Miscellaneous PHP Settings</h1>
 <ul>
-    <li>short_open_tag enabled: <?php echo status($short_open_tag) ?></li>
-    <?php if (!$short_open_tag) { ?>
-    <li><font color="red"><b>short_open_tags must be enabled to make Horde work.</b></font></li>
-    <?php } ?>
-    <li>magic_quotes_runtime set to Off: <?php echo status($magic_quotes_runtime); ?></li>
+    <li>magic_quotes_runtime disabled: <?php echo status($magic_quotes_runtime); ?></li>
     <?php if (!$magic_quotes_runtime) { ?>
     <li><font color="red"><b>magic_quotes_runtime may cause problems with database inserts, etc. Turn it off.</b></font></li>
     <?php } ?>
@@ -312,6 +341,14 @@ foreach ($versions as $module => $ver) {
     <?php if (!$file_uploads) { ?>
     <li><font color="orange"><b>file_uploads must be enabled for some features like sending emails with IMP.</b></font></li>
     <?php } ?>
+    <li>safe_mode disabled: <?php echo status($safe_mode) ?></li>
+    <?php if (!$safe_mode) { ?>
+    <li><font color="orange"><b>If safe_mode is enabled, Horde cannot set enviroment variables, which means Horde will be unable to translate the user interface into different languages.</b></font></li>
+    <?php } ?>
+    <li>trans_sid disabled: <?php echo status($trans_sid) ?></li>
+    <?php if (!$trans_sid) { ?>
+    <li><font color="orange"><b>Horde will work with session.trans_sid turned on, but you may see double session-ids in your URLs, and if the session name in php.ini differs from the session name configured in Horde, you may get two session ids and see other odd behavior. The URL-rewriting that trans_sid does also tends to break XHTML compliance.</b></font></li>
+    <?php } ?>
 </ul>
 
 <h1>PHP Sessions</h1>
@@ -331,13 +368,13 @@ foreach ($versions as $module => $ver) {
     <?php if ($pear && !$newpear) { ?>
         <li><font color="red">This version of PEAR is not recent enough. See the <a href="http://www.horde.org/pear/">Horde PEAR page</a> for details.</font></li>
     <?php } ?>
-    <li>Mail::RFC822 - <?php status($pearmail); ?></li>
+    <li>Mail - <?php status($pearmail); ?></li>
     <?php if ($pear && !$pearmail) { ?>
-        <li><font color="red">Make sure you're using a recent version of PEAR which includes the Mail class.</font></li>
+        <li><font color="red">Make sure you are using a recent version of PEAR which includes the Mail_RFC822 class.</font></li>
     <?php } ?>
     <li>Log - <?php status($pearlog); ?></li>
     <?php if ($pear && !$pearlog) { ?>
-        <li><font color="red">Make sure you're using a recent version of PEAR which includes the Log class.</font></li>
+        <li><font color="red">Make sure you are using a version of PEAR which includes the Log classes, or that you have installed the Log package seperately. See the INSTALL file for instructions on installing Log.</font></li>
     <?php } ?>
     <li>DB - <?php status($peardb); ?></li>
     <?php if ($pear && !$peardb) {
@@ -347,6 +384,18 @@ foreach ($versions as $module => $ver) {
                   <li><font color="red">You will need DB if you're using SQL drivers for preferences, contacts (Turba), etc.</font></li>
               <?php }
           } ?>
+    <li>Net_Socket - <?php status($pearsocket); ?></li>
+    <?php if ($pear && !$pearsocket) { ?>
+        <li><font color="red">Make sure you are using a version of PEAR which includes the Net_Socket class, or that you have installed the Net_Socket package seperately. See the INSTALL file for instructions on installing Net_Socket.</font></li>
+    <?php } ?>
+    <li>Date - <?php status($peardate); ?></li>
+    <?php if ($pear && !$peardate) { ?>
+        <li><font color="red">Horde requires the Date_Calc class for Kronolith to calculate dates.</font></li>
+    <?php } ?>
+    <li>HTML_Common/HTML_Select - <?php status($pearhtml); ?></li>
+    <?php if ($pear && !$pearhtml) { ?>
+        <li><font color="red">Horde requires the HTML_Common and HTML_Select classes only for Kronolith 1.0 to display forms correctly.</font></li>
+    <?php } ?>
     <?php if ($unkerr) { ?>
         <li><font color="red">Unknown error:</font> <?php echo $unkerr; ?></li>
     <?php } ?>
